===================================
 Rocky Series Release Notes
===================================

.. release-notes::
   :branch: stable/rocky
   :earliest-version: 2.0.0.0b1
   :ignore-notes:
     python3-support-d9657c136cad2a41.yaml,
     state-machine-37be751ed54c1c75.yaml
